import _Object$getPrototypeOf from 'babel-runtime/core-js/object/get-prototype-of';
import _classCallCheck from 'babel-runtime/helpers/classCallCheck';
import _createClass from 'babel-runtime/helpers/createClass';
import _possibleConstructorReturn from 'babel-runtime/helpers/possibleConstructorReturn';
import _inherits from 'babel-runtime/helpers/inherits';
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import Pane from './Pane';
import Overlay from './Overlay';
import Text from './Text';
import Button from './Button';
import theme from './theme';
var majorScale = theme.majorScale,
    minorScale = theme.minorScale;


var BottomSheetTopBar = function BottomSheetTopBar(_ref) {
  var left = _ref.left,
      right = _ref.right,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['left', 'right', 'children']);

  return React.createElement(
    Pane,
    _extends({ display: 'flex', top: '0', position: 'fixed', width: '100%', style: { zIndex: '10' }, alignItems: 'center', shadow: true, white: true }, props),
    React.createElement(
      Pane,
      { width: '33%', height: '100%', padding: minorScale(2), display: 'flex' },
      left
    ),
    React.createElement(
      Pane,
      { flexAuto: true, textAlign: 'center' },
      children
    ),
    React.createElement(
      Pane,
      { width: '33%', textAlign: 'right', padding: minorScale(2) },
      right
    )
  );
};

BottomSheetTopBar.propTypes = {
  left: PropTypes.node,
  right: PropTypes.node
};

BottomSheetTopBar.displayName = 'BottomSheetTopBar';

var BottomSheetCloseButton = function BottomSheetCloseButton(props) {
  return React.createElement(
    Button,
    _extends({ paddingX: majorScale(3) }, props),
    'Cancel'
  );
};

var slideInAnimation = css.keyframes('slideInAnimation', {
  from: {
    transform: 'translateY(100%)'
  },
  to: {
    transform: 'translateY(0)'
  }
});

var slideOutAnimation = css.keyframes('slideOutAnimation', {
  from: {
    transform: 'translateY(0)'
  },
  to: {
    transform: 'translateY(100%)'
  }
});

var BottomSheetPane = function BottomSheetPane(_ref2) {
  var slideOut = _ref2.slideOut,
      props = _objectWithoutProperties(_ref2, ['slideOut']);

  return React.createElement(Pane, _extends({}, css({
    transform: 'translateZ(0)',
    animation: (slideOut ? slideOutAnimation : slideInAnimation) + ' ' + theme.animationDuration.slow + ' ' + theme.animationEasing.deceleration
  }), props));
};

BottomSheetPane.propTypes = {
  slideOut: PropTypes.bool
};

BottomSheetPane.defaultProps = {
  tint: true,
  position: 'absolute',
  shadow: true,
  height: '100vh',
  paddingTop: majorScale(7),
  left: 0,
  right: 0,
  bottom: 0
};

BottomSheetPane.displayName = 'BottomSheetPane';

var BottomSheet = function (_Component) {
  _inherits(BottomSheet, _Component);

  function BottomSheet(props, context) {
    _classCallCheck(this, BottomSheet);

    var _this = _possibleConstructorReturn(this, (BottomSheet.__proto__ || _Object$getPrototypeOf(BottomSheet)).call(this, props, context));

    _this.handleClose = _this.handleClose.bind(_this);
    _this.handleAnimationEnd = _this.handleAnimationEnd.bind(_this);

    _this.state = {
      isClosing: false
    };
    return _this;
  }

  _createClass(BottomSheet, [{
    key: 'handleClose',
    value: function handleClose() {
      this.setState({ isClosing: true });
    }
  }, {
    key: 'handleAnimationEnd',
    value: function handleAnimationEnd() {
      if (!this.state.isClosing) return;
      this.props.onClose();
      this.setState({ isClosing: false });
    }
  }, {
    key: 'render',
    value: function render() {
      var _props = this.props,
          isOpen = _props.isOpen,
          children = _props.children,
          navigationBarLeft = _props.navigationBarLeft,
          navigationBarRight = _props.navigationBarRight,
          title = _props.title,
          props = _objectWithoutProperties(_props, ['isOpen', 'children', 'navigationBarLeft', 'navigationBarRight', 'title']);

      var isClosing = this.state.isClosing;


      if (!isOpen) return null;

      return React.createElement(
        Overlay,
        { onClick: this.handleClose, fadeOut: isClosing, onFadeEnd: this.handleAnimationEnd },
        React.createElement(
          BottomSheetPane,
          _extends({ onClick: function onClick(e) {
              return e.stopPropagation();
            }, slideOut: isClosing }, props),
          React.createElement(
            BottomSheetTopBar,
            { left: React.cloneElement(navigationBarLeft, { onClick: this.handleClose }), right: navigationBarRight },
            React.createElement(
              Text,
              { is: 'h2', textStyle: 'display4' },
              title
            )
          ),
          React.createElement(
            Pane,
            { style: { overflowY: 'auto' }, height: '100%' },
            children
          )
        )
      );
    }
  }]);

  return BottomSheet;
}(Component);

BottomSheet.propTypes = {
  isOpen: PropTypes.bool,
  onClose: PropTypes.func,
  navigationBarLeft: PropTypes.node,
  navigationBarRight: PropTypes.node,
  title: PropTypes.string
};

BottomSheet.defaultProps = {
  isOpen: true,
  navigationBarLeft: React.createElement(BottomSheetCloseButton, null),
  navigationBarRight: null,
  title: null
};

BottomSheet.displayName = 'BottomSheet';

export default BottomSheet;