import _Object$keys from 'babel-runtime/core-js/object/keys';
import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import cx from 'classnames';
import Box from './Box';
import theme from './theme';
import { ButtonAppearances } from 'evergreen-buttons';
var majorScale = theme.majorScale;


var getStyle = function getStyle(_ref) {
  var primary = _ref.primary,
      secondary = _ref.secondary,
      danger = _ref.danger;

  if (primary) return css(ButtonAppearances.green);
  if (danger) return css(ButtonAppearances.red);
  if (secondary) return css(ButtonAppearances.default); /* default */
  return '';
};

var baseStyles = css({
  textTransform: 'capitalize',
  border: 0,
  fontWeight: 400,
  textDecoration: 'none',
  WebkitAppearance: 'none',
  transition: theme.animationDuration.faster,
  transitionProperty: 'background-color, color, box-shadow, opacity',
  cursor: 'pointer',
  whiteSpace: 'nowrap',
  userSelect: 'none',
  verticalAlign: 'middle',
  borderRadius: 4,
  '&:active, &:focus': {
    outline: 'none'
  }
});

function useControlSizes(_ref2) {
  var size = _ref2.size,
      props = _objectWithoutProperties(_ref2, ['size']);

  var sizes = theme.controlSizes[size];
  var paddingX = {
    small: majorScale(2),
    default: majorScale(3)
  };

  return _extends({
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingX: paddingX[size]
  }, props);
}

var parseProps = function parseProps(_ref3) {
  var className = _ref3.className,
      primary = _ref3.primary,
      secondary = _ref3.secondary,
      danger = _ref3.danger,
      props = _objectWithoutProperties(_ref3, ['className', 'primary', 'secondary', 'danger']);

  return _extends({
    className: cx('' + baseStyles, '' + getStyle({ primary: primary, secondary: secondary, danger: danger }), className)
  }, props);
};

var Button = function Button(props) {
  return React.createElement(Box, parseProps(useControlSizes(props)));
};

Button.propTypes = _extends({}, Box.propTypes, {
  primary: PropTypes.bool,
  secondary: PropTypes.bool,
  danger: PropTypes.bool,
  size: PropTypes.oneOf(_Object$keys(theme.controlSizes))
});

Button.defaultProps = {
  is: 'button',
  display: 'inline-flex',
  alignItems: 'center',
  justifyContent: 'center',
  size: 'default',
  secondary: true
};

Button.displayName = 'Button';

export default Button;