import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import cx from 'classnames';
import Text from './Text';
import theme from './theme';

var getStyle = function getStyle(_ref) {
  var primary = _ref.primary,
      secondary = _ref.secondary,
      danger = _ref.danger;

  var intent = void 0;

  if (danger) intent = theme.intent.danger;else if (secondary) intent = theme.intent.secondary;else if (primary) intent = theme.intent.primary;

  if (!intent) return '';

  return css({
    color: intent.default.linkColor,
    '&:hover': {
      color: intent.hover.linkColor
    },
    '&:focus': {
      color: intent.focus.linkColor
    },
    '&:active, &.active': {
      color: intent.active.linkColor
    }
  });
};

var baseStyles = css({
  transition: 50,
  transitionProperty: 'background-color, color, box-shadow, opacity',
  textDecoration: 'none',
  '&.underline': {
    textDecoration: 'underline'
  },
  '&:active, &:focus': {
    outline: 'none'
  }
});

var parseProps = function parseProps(_ref2) {
  var underline = _ref2.underline,
      active = _ref2.active,
      primary = _ref2.primary,
      secondary = _ref2.secondary,
      danger = _ref2.danger,
      naked = _ref2.naked,
      className = _ref2.className,
      props = _objectWithoutProperties(_ref2, ['underline', 'active', 'primary', 'secondary', 'danger', 'naked', 'className']);

  return _extends({
    className: cx('' + baseStyles, '' + getStyle({ primary: primary, secondary: secondary, naked: naked, danger: danger }), underline && 'underline', active && 'active', className),
    is: active ? 'span' : 'a'
  }, props);
};

var Link = function Link(props) {
  return React.createElement(Text, parseProps(props));
};

Link.propTypes = _extends({}, Text.propTypes, {
  underline: PropTypes.bool,
  primary: PropTypes.bool,
  secondary: PropTypes.bool,
  danger: PropTypes.bool,
  active: PropTypes.bool
});

Link.defaultProps = {
  // underline: true,
  primary: true
};

Link.displayName = 'Link';

export default Link;