import _extends from 'babel-runtime/helpers/extends';
import _objectWithoutProperties from 'babel-runtime/helpers/objectWithoutProperties';
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import Box from './Box';
import { Body1 } from './TextStyles';
import theme from './theme';
var minorScale = theme.minorScale,
    majorScale = theme.majorScale;

import splitProps from './utils/splitProps';

var labelStyles = css({
  cursor: 'pointer'
});

var inputStyles = css({
  left: 0,
  opacity: 0,
  position: 'absolute',
  top: 0,
  zIndex: -1,
  '&:disabled + span': {
    backgroundColor: theme.colors.borderColor
  },
  '&:checked + span::before': {
    content: '""',
    position: 'absolute',
    height: '6px',
    width: '6px',
    top: '50%',
    left: '50%',
    transform: 'translate(-50%, -50%)',
    borderRadius: '50%',
    display: 'block',
    backgroundColor: theme.colors.activeColor
  }
});

var controlStyles = css({
  position: 'relative',
  top: '3px',
  height: majorScale(2),
  width: majorScale(2),
  borderRadius: '50%',
  boxShadow: 'inset 0 0 0 1px ' + theme.colors.borderColor,
  display: 'inline-block',
  marginRight: minorScale(3)
});

var Radio = function Radio(_ref) {
  var className = _ref.className,
      label = _ref.label,
      children = _ref.children,
      props = _objectWithoutProperties(_ref, ['className', 'label', 'children']);

  // Tries to treat this component as a single box
  var _splitProps = splitProps(props, /margin|width|height|display|position/gi),
      matchedProps = _splitProps.matchedProps,
      unmatchedProps = _splitProps.unmatchedProps;

  return React.createElement(
    Box,
    _extends({ is: 'label' }, matchedProps, labelStyles),
    React.createElement('input', _extends({ type: 'radio' }, inputStyles, unmatchedProps)),
    React.createElement('span', controlStyles),
    React.createElement(
      Body1,
      { is: 'span' },
      children
    )
  );
};

Radio.propTypes = {
  children: PropTypes.string,
  name: PropTypes.string.isRequired,
  value: PropTypes.string.isRequired,
  label: PropTypes.string
};

Radio.defaultProps = {
  marginY: majorScale(1),
  position: 'relative',
  display: 'block'
};

Radio.displayName = 'Radio';

export default Radio;