import _extends from 'babel-runtime/helpers/extends';
import React from 'react';
import PropTypes from 'prop-types';
import { css } from 'glamor';
import Pane from './Pane';
import Text from './Text';
import Link from './Link';
import Box from './Box';
import theme from './theme';
var minorScale = theme.minorScale,
    majorScale = theme.majorScale;


var SubNavigationBarLink = function SubNavigationBarLink(props) {
  return React.createElement(Link, _extends({}, css({
    '&:active, &:hover, &.active': {
      boxShadow: '0 1px ' + theme.rawColors.blue500
    }
  }), props));
};

SubNavigationBarLink.defaultProps = {
  secondary: true,
  textStyle: 'body1',
  paddingBottom: majorScale(2),
  marginX: minorScale(3)
};

var SubNavigationBarTitle = function SubNavigationBarTitle(props) {
  return React.createElement(Text, props);
};

SubNavigationBarTitle.defaultProps = {
  is: 'h2',
  textStyle: 'display4'
};

var SubNavigationBarPane = function SubNavigationBarPane(props) {
  return React.createElement(Pane, props);
};

SubNavigationBarPane.defaultProps = {
  display: 'flex',
  white: true,
  borderBottom: true
};

var SubNavigationBar = function SubNavigationBar(_ref) {
  var left = _ref.left,
      right = _ref.right,
      children = _ref.children;

  var leftChild = void 0;
  if (typeof left === 'string') {
    leftChild = React.createElement(
      SubNavigationBarTitle,
      null,
      left
    );
  } else {
    leftChild = left;
  }

  return React.createElement(
    SubNavigationBarPane,
    null,
    React.createElement(
      Pane,
      { width: '25%', padding: majorScale(2), flex: '0 0 auto' },
      leftChild
    ),
    React.createElement(
      Pane,
      { flexAuto: true, textAlign: 'center', display: 'flex', alignItems: 'flex-end', justifyContent: 'center' },
      children
    ),
    React.createElement(
      Pane,
      { width: '25%', textAlign: 'right', flex: '0 0 auto' },
      right
    )
  );
};

SubNavigationBar.propTypes = _extends({}, Box.propTypes, {
  left: PropTypes.oneOfType([PropTypes.node, PropTypes.string]),
  right: PropTypes.node
});

SubNavigationBar.defaultProps = {
  theme: theme
};

export { SubNavigationBar, SubNavigationBarTitle, SubNavigationBarLink };