import React from 'react';
import { storiesOf } from '@storybook/react';
import { App, Select, Pane, theme } from '../components';
import Content from './Content';
var majorScale = theme.majorScale;


export default function selectStory(module) {
  storiesOf('Select', module).add('usage', function () {
    return React.createElement(
      App,
      { white: true },
      React.createElement(
        Pane,
        { white: true, padding: majorScale(10) },
        React.createElement(
          Content,
          { markdown: true },
          '\n# Select\n\nThe Select component is a `select` element. Implement the `<Box />` component.\n\n## Select\'s are available in two sizes: small and default\n\n```\n<Select marginY={majorScale(2)} width={majorScale(30)}>\n  <option value=\'grapefruit\'>Grapefruit</option>\n  <option value=\'lime\'>Lime</option>\n</Select>\n\n<Select size=\'small\' marginY={majorScale(2)} width={majorScale(30)}>\n  <option value=\'coconut\'>Coconut</option>\n  <option value=\'mango\'>Mango</option>\n</Select>\n\n<Select disabled marginY={majorScale(2)} width={majorScale(30)}>\n  <option value=\'coconut\'>Coconut</option>\n  <option value=\'mango\'>Mango</option>\n</Select>\n```\n\n'
        ),
        React.createElement(
          Select,
          { marginY: majorScale(2), width: majorScale(30) },
          React.createElement(
            'option',
            { value: 'grapefruit' },
            'Grapefruit'
          ),
          React.createElement(
            'option',
            { value: 'lime' },
            'Lime'
          )
        ),
        React.createElement(
          Select,
          { size: 'small', marginY: majorScale(2), width: majorScale(30) },
          React.createElement(
            'option',
            { value: 'coconut' },
            'Coconut'
          ),
          React.createElement(
            'option',
            { value: 'mango' },
            'Mango'
          )
        ),
        React.createElement(
          Select,
          { disabled: true, marginY: majorScale(2), width: majorScale(30) },
          React.createElement(
            'option',
            { value: 'coconut' },
            'Coconut'
          ),
          React.createElement(
            'option',
            { value: 'mango' },
            'Mango'
          )
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\n\n# You can use the Select component in 3 ways:\n\n## 1. Pass in options directly\n\n```\n<Select inline>\n  <option value=\'grapefruit\'>Grapefruit</option>\n  <option value=\'lime\'>Lime</option>\n  <option value=\'coconut\'>Coconut</option>\n  <option value=\'mango\'>Mango</option>\n</Select>\n```\n\n'
        ),
        React.createElement(
          Select,
          { inline: true },
          React.createElement(
            'option',
            { value: 'grapefruit' },
            'Grapefruit'
          ),
          React.createElement(
            'option',
            { value: 'lime' },
            'Lime'
          ),
          React.createElement(
            'option',
            { value: 'coconut' },
            'Coconut'
          ),
          React.createElement(
            'option',
            { value: 'mango' },
            'Mango'
          )
        ),
        React.createElement(
          Content,
          { markdown: true },
          '\n\n## 2. Pass in options as an object through an `options` prop\n\nThis is the same API as in @segment/react-forms SelectField.\n\n```\n<Select inline options={[\n    {\n      label: \'Grapefruit\',\n      value: \'grapefruit\'\n    },\n    {\n      label: \'Lime\',\n      value: \'lime\'\n    },\n    {\n      label: \'Coconut\',\n      value: \'coconut\'\n    }\n  ]} />\n```\n\n        '
        ),
        React.createElement(Select, { inline: true, options: [{
            label: 'Grapefruit',
            value: 'grapefruit'
          }, {
            label: 'Lime',
            value: 'lime'
          }, {
            label: 'Coconut',
            value: 'coconut'
          }] }),
        React.createElement(
          Content,
          { markdown: true },
          '\n\n## 3. Pass in options as a string through an `options` prop\n\nThis is the same API as in @segment/react-forms SelectField.\n\n```\n<Select inline options={[\'Grapefruit\',\'Lime\', \'Coconut\']} />\n```\n\n        '
        ),
        React.createElement(Select, { inline: true, options: ['Grapefruit', 'Lime', 'Coconut'] }),
        React.createElement(
          Content,
          { markdown: true },
          '\nprop | version | type | default | description\n-----|---------|------| --------|----------\n`size`| v3.0.0 | `default`, `small` | `default` | as defined by `theme.controlSizes`\n`options` | v2 | [String] / [{ label: String, value: String }] | undefined | replaces children\n        '
        )
      )
    );
  }).add('standalone', function () {
    return React.createElement(
      Pane,
      { white: true, flex: '1' },
      React.createElement(
        Select,
        null,
        React.createElement(
          'option',
          { value: 'grapefruit' },
          'Grapefruit'
        ),
        React.createElement(
          'option',
          { value: 'lime' },
          'Lime'
        ),
        React.createElement(
          'option',
          { value: 'coconut' },
          'Coconut'
        ),
        React.createElement(
          'option',
          { value: 'mango' },
          'Mango'
        )
      )
    );
  }).add('inline', function () {
    return React.createElement(
      Pane,
      { white: true, flex: '1' },
      React.createElement(
        Select,
        { inline: true, marginRight: majorScale(2) },
        React.createElement(
          'option',
          { value: 'grapefruit' },
          'Grapefruit'
        ),
        React.createElement(
          'option',
          { value: 'lime' },
          'Lime'
        ),
        React.createElement(
          'option',
          { value: 'coconut' },
          'Coconut'
        ),
        React.createElement(
          'option',
          { value: 'mango' },
          'Mango'
        )
      ),
      React.createElement(
        Select,
        { inline: true, size: 'small' },
        React.createElement(
          'option',
          { value: 'grapefruit' },
          'Grapefruit'
        ),
        React.createElement(
          'option',
          { value: 'lime' },
          'Lime'
        ),
        React.createElement(
          'option',
          { value: 'coconut' },
          'Coconut'
        ),
        React.createElement(
          'option',
          { value: 'mango' },
          'Mango'
        )
      )
    );
  }).add('with spacing', function () {
    return React.createElement(
      Pane,
      { white: true, flex: '1' },
      React.createElement(
        Select,
        { marginX: majorScale(3) },
        React.createElement(
          'option',
          { value: 'grapefruit' },
          'Grapefruit'
        ),
        React.createElement(
          'option',
          { value: 'lime' },
          'Lime'
        ),
        React.createElement(
          'option',
          { value: 'coconut' },
          'Coconut'
        ),
        React.createElement(
          'option',
          { value: 'mango' },
          'Mango'
        )
      )
    );
  }).add('with width and centered', function () {
    return React.createElement(
      Pane,
      { white: true, clearfix: true, flex: '1' },
      React.createElement(
        Select,
        { width: '240px', marginX: 'auto', marginY: majorScale(10) },
        React.createElement(
          'option',
          { value: 'grapefruit' },
          'Grapefruit'
        ),
        React.createElement(
          'option',
          { value: 'lime' },
          'Lime'
        ),
        React.createElement(
          'option',
          { value: 'coconut' },
          'Coconut'
        ),
        React.createElement(
          'option',
          { value: 'mango' },
          'Mango'
        )
      )
    );
  });
}