import React from 'react';
import { storiesOf } from '@storybook/react';
import { App, Input, Pane, withLoader, theme } from '../components';
import Content from './Content';
var majorScale = theme.majorScale;


var LoaderInput = withLoader(Input);
var LoaderInputStyled = withLoader(Input, {
  width: majorScale(8),
  height: majorScale(8),
  marginY: majorScale(4)
});

export default function inputStory(module) {
  storiesOf('withLoader', module).add('usage', function () {
    return React.createElement(
      App,
      { white: true },
      React.createElement(
        Pane,
        { white: true, padding: majorScale(10) },
        React.createElement(
          Content,
          { markdown: true },
          '\n# withLoader\n\nHigher Order Component for adding loading functionality to a component. Uses the `<Spinner />` component.\n\n```\nconst LoaderInput = withLoader(Input)\n<LoaderInput isLoading />\n```\n\n'
        ),
        React.createElement(LoaderInput, { isLoading: true }),
        React.createElement(
          Content,
          { markdown: true },
          '\n`withLoader(component, spinnerProps)`\n\nprop | type | default | description\n-----|------| --------|-------------\n`component` | function | undefined | Component constructor\n`spinnerProps` | object | `{ marginX: \'auto\', marginY: majorScale(8) }` | Custom styles for `<Spinner />` (merged with default)\n'
        )
      )
    );
  }).add('standalone', function () {
    return React.createElement(LoaderInput, { isLoading: true });
  }).add('with spinner props', function () {
    return React.createElement(LoaderInputStyled, { isLoading: true });
  });
}