'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _glamor = require('glamor');

var _Box = require('./Box');

var _Box2 = _interopRequireDefault(_Box);

var _DoubleTriangle = require('./DoubleTriangle');

var _DoubleTriangle2 = _interopRequireDefault(_DoubleTriangle);

var _theme = require('./theme');

var _theme2 = _interopRequireDefault(_theme);

var _splitProps2 = require('./utils/splitProps');

var _splitProps3 = _interopRequireDefault(_splitProps2);

var _evergreenSelect = require('evergreen-select');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

var minorScale = _theme2.default.minorScale,
    majorScale = _theme2.default.majorScale,
    controlSizes = _theme2.default.controlSizes;


var selectStyles = (0, _glamor.css)(_evergreenSelect.SelectAppearances.default);
var SelectWrapperBox = function SelectWrapperBox(props) {
  return _react2.default.createElement(_Box2.default, props);
};
SelectWrapperBox.displayName = 'SelectWrapperBox';

var iconStyles = (0, _glamor.css)({
  position: 'absolute',
  transform: 'translateY(-50%)',
  pointerEvents: 'none',
  top: '50%'
});
var SelectIcon = function SelectIcon(props) {
  return _react2.default.createElement(_DoubleTriangle2.default, _extends({ className: '' + iconStyles }, props));
};
SelectIcon.displayName = 'SelectIcon';

var renderOptions = function renderOptions() {
  var options = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : [];

  return options.map(function (item) {
    return (typeof item === 'undefined' ? 'undefined' : _typeof(item)) === 'object' ? item : { value: item, label: item };
  }).map(function (item, i) {
    return _react2.default.createElement(
      'option',
      { key: 'option__' + item.value + '__' + i, value: item.value },
      item.label
    );
  });
};

function useControlSizes(_ref) {
  var size = _ref.size,
      inline = _ref.inline,
      props = _objectWithoutProperties(_ref, ['size', 'inline']);

  var sizes = controlSizes[size];

  return _extends({
    display: inline ? 'inline-flex' : 'flex',
    minHeight: sizes.minHeight,
    minWidth: sizes.minWidth,
    textStyle: sizes.textStyle,
    paddingLeft: size === 'small' ? minorScale(3) : majorScale(2),
    paddingRight: size === 'small' ? majorScale(3) : majorScale(4)
  }, props);
}

var Select = function Select(_ref2) {
  var options = _ref2.options,
      children = _ref2.children,
      props = _objectWithoutProperties(_ref2, ['options', 'children']);

  var _splitProps = (0, _splitProps3.default)(useControlSizes(props), /margin|width|height|display|flex|alignItems|justifyContent|flexDirection|flexGrow|flexShrink/gi),
      matchedProps = _splitProps.matchedProps,
      unmatchedProps = _splitProps.unmatchedProps;

  return _react2.default.createElement(
    SelectWrapperBox,
    _extends({ position: 'relative' }, matchedProps),
    _react2.default.createElement(SelectIcon, {
      right: props.size === 'small' ? majorScale(1) : minorScale(3)
    }),
    _react2.default.createElement(
      _Box2.default,
      _extends({ className: '' + selectStyles, flex: '1' }, unmatchedProps),
      options ? renderOptions(options) : children
    )
  );
};

Select.propTypes = {
  options: _propTypes2.default.oneOfType([_propTypes2.default.arrayOf(_propTypes2.default.string), _propTypes2.default.arrayOf(_propTypes2.default.shape({
    value: _propTypes2.default.string,
    label: _propTypes2.default.string
  }))]),
  size: _propTypes2.default.oneOf(Object.keys(controlSizes)).isRequired,
  inline: _propTypes2.default.bool.isRequired
};

Select.defaultProps = {
  is: 'select',
  rounded: true,
  size: 'default',
  inline: false
};

Select.displayName = 'Select';

exports.default = Select;