'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _color = require('color');

var _color2 = _interopRequireDefault(_color);

var _evergreenColors = require('evergreen-colors');

var _evergreenColors2 = _interopRequireDefault(_evergreenColors);

var _evergreenTypography = require('evergreen-typography');

var _evergreenLayers = require('evergreen-layers');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var rawColors = {
  green900: _evergreenColors2.default.green['900'], //  '#21523A',
  green800: _evergreenColors2.default.green['800'], //  '#2B6B4C',
  green700: _evergreenColors2.default.green['700'], //  '#35855E',
  green600: _evergreenColors2.default.green['600'], //  '#3F9E70',
  green500: _evergreenColors2.default.green['500'], //  '#49B882',
  green400: _evergreenColors2.default.green['300'], //  '#54D194',
  green300: _evergreenColors2.default.green['150'], //  '#84DBB1',
  green200: _evergreenColors2.default.green['100'], //  '#A8F0CD',
  green100: _evergreenColors2.default.green['50'], //  '#CCFFE6',
  green50: _evergreenColors2.default.green['10'], //    '#e4f7ed',

  blue900: _evergreenColors2.default.blue['900'], // '#0A2A48',
  blue800: _evergreenColors2.default.blue['800'], // '#004585',
  blue700: _evergreenColors2.default.blue['700'], // '#00529E',
  blue600: _evergreenColors2.default.blue['600'], // '#005FB8',
  blue500: _evergreenColors2.default.blue['500'], // '#006CD1',
  blue400: _evergreenColors2.default.blue['300'], // '#1785EB',
  blue300: _evergreenColors2.default.blue['150'], // '#5EA7EB',
  blue200: _evergreenColors2.default.blue['80'], // '#99CEFF',
  blue100: _evergreenColors2.default.blue['40'], // '#C7E4FF',
  blue50: _evergreenColors2.default.blue['10'], // '#EAF3FB',

  peach500: _evergreenColors2.default.yellow['500'], // '#FCC79B',
  peach400: _evergreenColors2.default.yellow['100'], // '#FAE0CB',
  peach50: _evergreenColors2.default.yellow['20'], // '#FCF1E8',

  pink500: _evergreenColors2.default.red['500'], //  '#E365A6',
  pink400: _evergreenColors2.default.red['100'], //  '#FFDAED',
  pink50: _evergreenColors2.default.red['10'], // '#FAEFF5',

  grey500: _evergreenColors2.default.neutral['800'], // '#193652',
  grey400: _evergreenColors2.default.neutral['500'], // '#3D556B',
  grey300: _evergreenColors2.default.neutral['100'], // '#8FA1B3',
  grey200: _evergreenColors2.default.neutral['30'], // '#D9E3ED',
  grey100: _evergreenColors2.default.neutral['10'], // '#F2F5F7',
  grey50: _evergreenColors2.default.neutral['5'], // '#F9FAFB',

  white: '#FFFFFF'
};

var textColors = {
  title: rawColors.grey500,
  body: rawColors.grey400,
  muted: rawColors.grey300,
  white: rawColors.white
};

var colors = {
  primary: rawColors.green500,
  dark: _evergreenColors2.default.neutral['900'],
  borderColor: rawColors.grey200,
  activeColor: rawColors.blue500,

  backgroundTint1: rawColors.grey50,
  backgroundTint2: rawColors.grey100,

  white: rawColors.white,

  danger: rawColors.pink500,
  success: rawColors.green500,
  question: rawColors.blue500,
  warning: rawColors.peach500
};

var majorScale = function majorScale(x) {
  return x * 8 + 'px';
};
var minorScale = function minorScale(x) {
  return x * 4 + 'px';
};

/**
 * Preset sizes for input and button elements
 */

var controlSizes = {
  small: {
    minHeight: majorScale(4),
    minWidth: majorScale(4),
    textStyle: 'body2'
  },
  default: {
    minHeight: majorScale(5),
    minWidth: majorScale(5),
    textStyle: 'body1'
  }
};

var fonts = {
  display: '"SF UI Display", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
  ui: '"SF UI Text", -apple-system, BlinkMacSystemFont, "Segoe UI", Roboto, Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"',
  mono: '"SF Mono", "Monaco", "Inconsolata", "Fira Mono", "Droid Sans Mono", "Source Code Pro", monospace'
};

// backwards compatibility
fonts.sans = fonts.ui;

var textStyles = {};

textStyles.display1 = _extends({}, _evergreenTypography.TextStyles['600'], {
  fontFamily: fonts.display,
  fontWeight: '500',
  fontSize: '22px'
});

textStyles.display2 = _extends({}, _evergreenTypography.TextStyles['600'], {
  fontFamily: fonts.display,
  fontWeight: '500'
});

textStyles.display3 = _extends({}, _evergreenTypography.TextStyles['500'], {
  fontFamily: fonts.display,
  fontSize: '18px',
  fontWeight: '500'
});

textStyles.display4 = _extends({}, _evergreenTypography.TextStyles['500'], {
  fontFamily: fonts.display,
  fontSize: '16px',
  fontWeight: '500'
});

textStyles.display5 = _extends({}, _evergreenTypography.TextStyles['400'], {
  fontFamily: fonts.ui,
  fontWeight: '500'
});

textStyles.body1 = _extends({}, _evergreenTypography.TextStyles['400'], {
  fontFamily: fonts.ui,
  fontSize: '14px',
  fontWeight: '400'
});

textStyles.body2 = _extends({}, _evergreenTypography.TextStyles['300'], {
  fontFamily: fonts.ui
});

textStyles.mono = {
  fontFamily: fonts.mono,
  fontSize: '13px',
  fontWeight: '300',
  lineHeight: '21px',
  letterSpacing: '0'
};

textStyles.caps1 = _extends({}, _evergreenTypography.TextStyles['200'], {
  fontFamily: fonts.ui
});

textStyles.caps2 = _extends({}, _evergreenTypography.TextStyles['100'], {
  fontFamily: fonts.ui
});

textStyles.pill = {
  fontFamily: fonts.ui,
  fontSize: '10px',
  fontWeight: '500',
  lineHeight: majorScale(2),
  letterSpacing: '0.08em',
  textAlign: 'center'
};

var animationEasing = {
  standard: 'cubic-bezier(0.4, 0.0, 0.2, 1)',
  deceleration: 'cubic-bezier(0.0, 0.0, 0.2, 1)',
  acceleration: 'cubic-bezier(0.4, 0.0, 1, 1)',
  sharp: 'cubic-bezier(0.4, 0.0, 0.6, 1)',
  spring: 'cubic-bezier(0.175, 0.885, 0.320, 1.175)'
};

// https://material.io/guidelines/motion/duration-easing.html#duration-easing-common-durations
var animationDuration = {
  faster: '150ms',
  fast: '225ms',
  slow: '400ms'
};

var intent = {
  primary: {
    default: {
      linkColor: colors.primary,
      backgroundColor: colors.primary,
      textColor: colors.white
    },
    hover: {
      linkColor: (0, _color2.default)(colors.primary).lighten(0.2).saturate(0.2).rgb().string(),
      backgroundColor: rawColors.green400,
      textColor: colors.white
    },
    active: {
      linkColor: colors.primary,
      backgroundColor: colors.primary,
      textColor: colors.white
    },
    focus: {
      linkColor: colors.primary,
      backgroundColor: rawColors.green400,
      textColor: colors.white
    }
  },
  secondary: {
    default: {
      linkColor: textColors.body,
      backgroundColor: rawColors.white,
      textColor: textColors.body,
      border: '1px solid ' + colors.borderColor
    },
    hover: {
      linkColor: textColors.body,
      backgroundColor: rawColors.white,
      textColor: textColors.body,
      border: '1px solid ' + (0, _color2.default)(colors.borderColor).darken(0.1).rgb().string()
    },
    active: {
      linkColor: colors.activeColor,
      backgroundColor: colors.backgroundTint1,
      textColor: textColors.title,
      border: '1px solid ' + (0, _color2.default)(colors.borderColor).darken(0.1).rgb().string(),
      boxShadow: '0 2px 4px 0 rgba(0, 108, 209, 0.08)'
    },
    focus: {
      linkColor: colors.darkTint,
      backgroundColor: colors.white,
      textColor: textColors.body,
      border: '1px solid ' + (0, _color2.default)(colors.borderColor).darken(0.1).rgb().string(),
      boxShadow: '0 2px 4px 0 rgba(0, 108, 209, 0.08)'
    }
  },
  danger: {
    default: {
      linkColor: colors.danger,
      backgroundColor: colors.danger,
      textColor: colors.white
    },
    hover: {
      linkColor: colors.danger,
      backgroundColor: (0, _color2.default)(colors.danger).whiten(0.3).rgb().string(),
      textColor: textColors.white
    },
    active: {
      linkColor: colors.danger,
      backgroundColor: colors.danger,
      textColor: textColors.white
    },
    focus: {
      linkColor: colors.danger,
      backgroundColor: [(0, _color2.default)(colors.danger).whiten(0.3).rgb().string()],
      textColor: textColors.white
    }
  }
};

var controlStateStyles = {
  default: {
    backgroundColor: colors.white,
    color: textColors.body,
    border: '1px solid ' + colors.borderColor,
    transition: 'all ' + animationDuration.faster + ' ' + animationEasing.standard
  },
  hover: {
    backgroundColor: rawColors.white,
    color: textColors.body,
    border: '1px solid ' + (0, _color2.default)(colors.borderColor).darken(0.1).rgb().string()
  },
  active: {
    backgroundColor: rawColors.grey100,
    color: textColors.body,
    border: '1px solid ' + (0, _color2.default)(colors.borderColor).darken(0.1).rgb().string()
  },
  focus: {
    backgroundColor: rawColors.grey100,
    color: textColors.body,
    border: '1px solid ' + (0, _color2.default)(colors.borderColor).darken(0.1).rgb().string(),
    boxShadow: '0 2px 4px 0 rgba(0, 108, 209, 0.08)'
  },
  checked: {
    backgroundColor: colors.activeColor,
    color: colors.white,
    border: '1px solid transparent'
  },
  disabled: {
    backgroundColor: rawColors.grey50,
    color: textColors.muted,
    border: '1px solid ' + colors.borderColor
  }
};

var backgrounds = {};

backgrounds.dark = {
  textColor: colors.white,
  backgroundColor: colors.dark,
  borderColor: colors.borderColor, // TODO: implement/think about dark borderColor
  borderColorInteractive: colors.borderColor
};

backgrounds.white = {
  textColor: textColors.body,
  backgroundColor: colors.white,
  borderColor: colors.borderColor,
  borderColorInteractive: colors.primary
};

backgrounds.tint1 = backgrounds.tint = {
  textColor: textColors.body,
  backgroundColor: rawColors.grey50,
  borderColor: colors.borderColor,
  borderColorInteractive: colors.primary
};

backgrounds.tint2 = {
  textColor: textColors.body,
  backgroundColor: rawColors.grey100,
  borderColor: colors.borderColor,
  borderColorInteractive: colors.primary
};

var activeClassName = 'evergreen-active';

var theme = {
  activeClassName: activeClassName,
  majorScale: majorScale,
  minorScale: minorScale,
  animationEasing: animationEasing,
  animationDuration: animationDuration,
  rawColors: rawColors,
  backgrounds: backgrounds,
  fonts: fonts,
  textColors: textColors,
  textStyles: textStyles,
  colors: colors,
  intent: intent,
  controlStateStyles: controlStateStyles,
  controlSizes: controlSizes,
  borderRadius: ['4px', '8px'],
  popoverShadow: '0 2px 4px rgba(0,0,0,0.04), 0 8px 24px rgba(0,0,0,0.02)',
  shadows: [_evergreenLayers.ElevationStyles[2], _evergreenLayers.ElevationStyles[1]]
};

exports.default = theme;