'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = selectStory;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _react3 = require('@storybook/react');

var _components = require('../components');

var _Content = require('./Content');

var _Content2 = _interopRequireDefault(_Content);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var majorScale = _components.theme.majorScale;
function selectStory(module) {
  (0, _react3.storiesOf)('Select', module).add('usage', function () {
    return _react2.default.createElement(
      _components.App,
      { white: true },
      _react2.default.createElement(
        _components.Pane,
        { white: true, padding: majorScale(10) },
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\n# Select\n\nThe Select component is a `select` element. Implement the `<Box />` component.\n\n## Select\'s are available in two sizes: small and default\n\n```\n<Select marginY={majorScale(2)} width={majorScale(30)}>\n  <option value=\'grapefruit\'>Grapefruit</option>\n  <option value=\'lime\'>Lime</option>\n</Select>\n\n<Select size=\'small\' marginY={majorScale(2)} width={majorScale(30)}>\n  <option value=\'coconut\'>Coconut</option>\n  <option value=\'mango\'>Mango</option>\n</Select>\n\n<Select disabled marginY={majorScale(2)} width={majorScale(30)}>\n  <option value=\'coconut\'>Coconut</option>\n  <option value=\'mango\'>Mango</option>\n</Select>\n```\n\n'
        ),
        _react2.default.createElement(
          _components.Select,
          { marginY: majorScale(2), width: majorScale(30) },
          _react2.default.createElement(
            'option',
            { value: 'grapefruit' },
            'Grapefruit'
          ),
          _react2.default.createElement(
            'option',
            { value: 'lime' },
            'Lime'
          )
        ),
        _react2.default.createElement(
          _components.Select,
          { size: 'small', marginY: majorScale(2), width: majorScale(30) },
          _react2.default.createElement(
            'option',
            { value: 'coconut' },
            'Coconut'
          ),
          _react2.default.createElement(
            'option',
            { value: 'mango' },
            'Mango'
          )
        ),
        _react2.default.createElement(
          _components.Select,
          { disabled: true, marginY: majorScale(2), width: majorScale(30) },
          _react2.default.createElement(
            'option',
            { value: 'coconut' },
            'Coconut'
          ),
          _react2.default.createElement(
            'option',
            { value: 'mango' },
            'Mango'
          )
        ),
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\n\n# You can use the Select component in 3 ways:\n\n## 1. Pass in options directly\n\n```\n<Select inline>\n  <option value=\'grapefruit\'>Grapefruit</option>\n  <option value=\'lime\'>Lime</option>\n  <option value=\'coconut\'>Coconut</option>\n  <option value=\'mango\'>Mango</option>\n</Select>\n```\n\n'
        ),
        _react2.default.createElement(
          _components.Select,
          { inline: true },
          _react2.default.createElement(
            'option',
            { value: 'grapefruit' },
            'Grapefruit'
          ),
          _react2.default.createElement(
            'option',
            { value: 'lime' },
            'Lime'
          ),
          _react2.default.createElement(
            'option',
            { value: 'coconut' },
            'Coconut'
          ),
          _react2.default.createElement(
            'option',
            { value: 'mango' },
            'Mango'
          )
        ),
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\n\n## 2. Pass in options as an object through an `options` prop\n\nThis is the same API as in @segment/react-forms SelectField.\n\n```\n<Select inline options={[\n    {\n      label: \'Grapefruit\',\n      value: \'grapefruit\'\n    },\n    {\n      label: \'Lime\',\n      value: \'lime\'\n    },\n    {\n      label: \'Coconut\',\n      value: \'coconut\'\n    }\n  ]} />\n```\n\n        '
        ),
        _react2.default.createElement(_components.Select, { inline: true, options: [{
            label: 'Grapefruit',
            value: 'grapefruit'
          }, {
            label: 'Lime',
            value: 'lime'
          }, {
            label: 'Coconut',
            value: 'coconut'
          }] }),
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\n\n## 3. Pass in options as a string through an `options` prop\n\nThis is the same API as in @segment/react-forms SelectField.\n\n```\n<Select inline options={[\'Grapefruit\',\'Lime\', \'Coconut\']} />\n```\n\n        '
        ),
        _react2.default.createElement(_components.Select, { inline: true, options: ['Grapefruit', 'Lime', 'Coconut'] }),
        _react2.default.createElement(
          _Content2.default,
          { markdown: true },
          '\nprop | version | type | default | description\n-----|---------|------| --------|----------\n`size`| v3.0.0 | `default`, `small` | `default` | as defined by `theme.controlSizes`\n`options` | v2 | [String] / [{ label: String, value: String }] | undefined | replaces children\n        '
        )
      )
    );
  }).add('standalone', function () {
    return _react2.default.createElement(
      _components.Pane,
      { white: true, flex: '1' },
      _react2.default.createElement(
        _components.Select,
        null,
        _react2.default.createElement(
          'option',
          { value: 'grapefruit' },
          'Grapefruit'
        ),
        _react2.default.createElement(
          'option',
          { value: 'lime' },
          'Lime'
        ),
        _react2.default.createElement(
          'option',
          { value: 'coconut' },
          'Coconut'
        ),
        _react2.default.createElement(
          'option',
          { value: 'mango' },
          'Mango'
        )
      )
    );
  }).add('inline', function () {
    return _react2.default.createElement(
      _components.Pane,
      { white: true, flex: '1' },
      _react2.default.createElement(
        _components.Select,
        { inline: true, marginRight: majorScale(2) },
        _react2.default.createElement(
          'option',
          { value: 'grapefruit' },
          'Grapefruit'
        ),
        _react2.default.createElement(
          'option',
          { value: 'lime' },
          'Lime'
        ),
        _react2.default.createElement(
          'option',
          { value: 'coconut' },
          'Coconut'
        ),
        _react2.default.createElement(
          'option',
          { value: 'mango' },
          'Mango'
        )
      ),
      _react2.default.createElement(
        _components.Select,
        { inline: true, size: 'small' },
        _react2.default.createElement(
          'option',
          { value: 'grapefruit' },
          'Grapefruit'
        ),
        _react2.default.createElement(
          'option',
          { value: 'lime' },
          'Lime'
        ),
        _react2.default.createElement(
          'option',
          { value: 'coconut' },
          'Coconut'
        ),
        _react2.default.createElement(
          'option',
          { value: 'mango' },
          'Mango'
        )
      )
    );
  }).add('with spacing', function () {
    return _react2.default.createElement(
      _components.Pane,
      { white: true, flex: '1' },
      _react2.default.createElement(
        _components.Select,
        { marginX: majorScale(3) },
        _react2.default.createElement(
          'option',
          { value: 'grapefruit' },
          'Grapefruit'
        ),
        _react2.default.createElement(
          'option',
          { value: 'lime' },
          'Lime'
        ),
        _react2.default.createElement(
          'option',
          { value: 'coconut' },
          'Coconut'
        ),
        _react2.default.createElement(
          'option',
          { value: 'mango' },
          'Mango'
        )
      )
    );
  }).add('with width and centered', function () {
    return _react2.default.createElement(
      _components.Pane,
      { white: true, clearfix: true, flex: '1' },
      _react2.default.createElement(
        _components.Select,
        { width: '240px', marginX: 'auto', marginY: majorScale(10) },
        _react2.default.createElement(
          'option',
          { value: 'grapefruit' },
          'Grapefruit'
        ),
        _react2.default.createElement(
          'option',
          { value: 'lime' },
          'Lime'
        ),
        _react2.default.createElement(
          'option',
          { value: 'coconut' },
          'Coconut'
        ),
        _react2.default.createElement(
          'option',
          { value: 'mango' },
          'Mango'
        )
      )
    );
  });
}